import React, { useEffect, useState } from 'react'
import { Routes, Route, Navigate } from 'react-router-dom'
import { Toaster } from 'react-hot-toast'
import Layout from './components/Layout'
import Dashboard from './pages/Dashboard'
import TicketBalances from './pages/TicketBalances'
import CompanyValidation from './pages/CompanyValidation'
import UserValidation from './pages/UserValidation'
import Login from './pages/Login'

function App() {
  const [isAuthenticated, setIsAuthenticated] = useState(false)

  useEffect(() => {
    // Check if user is authenticated
    const authStatus = localStorage.getItem('isAuthenticated')
    const user = localStorage.getItem('user')
    if (authStatus === 'true' && user) {
      setIsAuthenticated(true)
    }
  }, [])

  const handleLogin = () => {
    setIsAuthenticated(true)
  }

  const handleLogout = () => {
    localStorage.removeItem('user')
    localStorage.removeItem('isAuthenticated')
    setIsAuthenticated(false)
  }

  if (!isAuthenticated) {
    return (
        <>
          <Login onLogin={handleLogin} />
          <Toaster position="top-right" />
        </>
    )
  }

  return (
      <>
        <Layout onLogout={handleLogout}>
          <Routes>
            <Route path="/" element={<Dashboard />} />
            <Route path="/tickets" element={<TicketBalances />} />
            <Route path="/companies" element={<CompanyValidation />} />
            <Route path="/users" element={<UserValidation />} />
            <Route path="*" element={<Navigate to="/" replace />} />
          </Routes>
        </Layout>
        <Toaster position="top-right" />
      </>
  )
}

export default App